"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHandleInsertSerialOperations = void 0;
const gql_1 = require("@deep-foundation/deeplinks/imports/gql");
/**
 * Gets insert serial operations for handle
 *
 * @example
```ts

```
 */
function getHandleInsertSerialOperations(param) {
    return __awaiter(this, void 0, void 0, function* () {
        const { deep, triggerTypeLinkId, containerLinkId = deep.linkId, containTypeLinkId = yield deep.id('@deep-foundation/core', 'Contain'), containValue, } = param;
        if (!deep) {
            throw new Error(`DeepClient is required`);
        }
        if (!triggerTypeLinkId) {
            throw new Error(`Trigger type link id is required`);
        }
        if (!containerLinkId) {
            throw new Error(`Container link id is required`);
        }
        let linkIds = param.linkIds;
        if (!linkIds) {
            const reservedLinkIds = yield deep.reserve(2);
            linkIds = {
                handleLinkId: reservedLinkIds[0],
                containLinkId: reservedLinkIds[1],
            };
        }
        const serialOperations = [];
        const handleInsertSerialOperation = (0, gql_1.createSerialOperation)({
            type: 'insert',
            table: 'links',
            objects: {
                id: linkIds.handleLinkId,
                type_id: param.handleTypeLinkId,
                from_id: triggerTypeLinkId,
                to_id: param.handlerLinkId,
            },
        });
        serialOperations.push(handleInsertSerialOperation);
        const containInsertSerialOperation = (0, gql_1.createSerialOperation)({
            type: 'insert',
            table: 'links',
            objects: {
                type_id: containTypeLinkId,
                from_id: containerLinkId,
                to_id: linkIds.handleLinkId,
            },
        });
        serialOperations.push(containInsertSerialOperation);
        if (containValue) {
            const valueOfContainInsertSerialOperation = (0, gql_1.createSerialOperation)({
                type: 'insert',
                table: 'strings',
                objects: {
                    link_id: linkIds.containLinkId,
                    value: containValue,
                },
            });
            serialOperations.push(valueOfContainInsertSerialOperation);
        }
        return serialOperations;
    });
}
exports.getHandleInsertSerialOperations = getHandleInsertSerialOperations;
