import { DeepClient } from '@deep-foundation/deeplinks/imports/client';
import { Handle } from './handle';
/**
 * Inserts a handle and contain it if {@link InsertHandleParam.containerLinkId} is not null
 *
 * @example
 * #### Insert a handle link
```ts
await insertHandle({
   deep,
   handle: Handle.Insert \/\* Handle.Update, Handle.Delete \*\/,
   triggerTypeLinkId: await deep.id(deep.linkId, "MyType"),
   containerLinkId: deep.linkId
})
```
 */
export declare function insertHandle(param: InsertHandleParam): Promise<import("@deep-foundation/deeplinks/imports/client").DeepClientResult<{
    id: any;
}[]>>;
export interface InsertHandleParam {
    /**
     * DeepClient instance
     */
    deep: DeepClient;
    /**
     * Type of Handle
     */
    handle: Handle;
    /**
     * Link id that will be handled
     */
    triggerTypeLinkId: number;
    /**
     * Link id of container
     *
     * @defaultValue {@link InsertHandleParam.deep.linkId} if undefined
     */
    containerLinkId?: number | null;
}
